pub enum Retryable<T> {
Retry,
Error(T),
}Expand description
Retryable wraps an error type and may ask manager to retry sending a command, this is useful for ctap1 where token will reply with “condition not sufficient” because user needs to press the button.
Variants
Implementations