pub enum StatusUpdate {
DeviceAvailable {
dev_info: U2FDeviceInfo,
},
DeviceUnavailable {
dev_info: U2FDeviceInfo,
},
Success {
dev_info: U2FDeviceInfo,
},
PinError(PinError, Sender<Pin>),
SelectDeviceNotice,
DeviceSelected(U2FDeviceInfo),
}Variants
DeviceAvailable
Device found
Fields

dev_info: U2FDeviceInfoDevice got removed
Success
We successfully finished the register or sign request
Fields

dev_info: U2FDeviceInfoPinError(PinError, Sender<Pin>)
Sent if a PIN is needed (or was wrong), or some other kind of PIN-related error occurred. The Sender is for sending back a PIN (if needed).
SelectDeviceNotice
Sent, if multiple devices are found and the user has to select one
DeviceSelected(U2FDeviceInfo)
Sent, once a device was selected (either automatically or by user-interaction) and the register or signing process continues with this device